==> gmetadom_0.0.3-6.tar.gz: gmetadom-0.0.3/src/gdome_cpp_smart/basic/GdomeSmartDOMDOMException.cc <==
/* This file is part of MetaDOM
 * a generic bind package for the Document Object Model API.
 * Copyright (C) 2001  Luca Padovani <luca.padovani@cs.unibo.it>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more information, please visit the author's home page
 * http://www.cs.unibo.it/~lpadovan
 * or send an email to <luca.padovani@cs.unibo.it>
 */

#include <config.h>

#include "GdomeSmartDOMDOMString.hh"
#include "GdomeSmartDOMDOMException.hh"

namespace GdomeSmartDOM {

DOMException::DOMException(unsigned short c) : code(c) { }

DOMException::DOMException(unsigned short c, const DOMString& s) : code(c), msg(s) { }

DOMException::DOMException(const DOMException& exc)
{
  *this = exc;
}

DOMException& DOMException::operator=(const DOMException& exc)
{
  code = exc.code;
  msg = exc.msg;
  return *this;
}

}

==> gmetadom_0.2.6.orig.tar.gz: gmetadom-0.2.6/src/gdome_cpp_smart/basic/GdomeSmartDOMDOMException.cc <==
/* This file is part of MetaDOM
 * a generic bind package for the Document Object Model API.
 * Copyright (C) 2001  Luca Padovani <luca.padovani@cs.unibo.it>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * For more information, please visit the author's home page
 * http://www.cs.unibo.it/~lpadovan
 * or send an email to <luca.padovani@cs.unibo.it>
 */

#include <config.h>

#include "GdomeSmartDOMGdomeString.hh"
#include "GdomeSmartDOMDOMException.hh"

namespace GdomeSmartDOM {

DOMException::DOMException(unsigned short c) : code(c) { }

DOMException::DOMException(unsigned short c, const GdomeString& s) : code(c), msg(s) { }

DOMException::DOMException(const DOMException& exc)
{
  *this = exc;
}

DOMException& DOMException::operator=(const DOMException& exc)
{
  code = exc.code;
  msg = exc.msg;
  return *this;
}

}
